Module: ViewFu::ControllerExtensions
- Defined in:
- lib/view_fu/controller_extensions.rb
Instance Method Summary collapse
-
#helpers ⇒ Object
allows us to say "helpers." anywhere in our controllers.
-
#production? ⇒ Boolean
checks to see if app is in production mode.
Instance Method Details
#helpers ⇒ Object
allows us to say "helpers." anywhere in our controllers
4 5 6 |
# File 'lib/view_fu/controller_extensions.rb', line 4 def helpers self.class.helpers end |
#production? ⇒ Boolean
checks to see if app is in production mode
9 10 11 |
# File 'lib/view_fu/controller_extensions.rb', line 9 def production? Rails.env == "production" end |